#
# spec file for package vncmanager
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define vncgroup vnc
%define vncuser vnc

Name:           vncmanager
Version:        1.0.2
Release:        lp151.4.4
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_program_options-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libgnutls-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-devel
BuildRequires:  systemd-rpm-macros
Requires(post): xorg-x11-Xvnc
Requires:       vncmanager-greeter
Requires:       xorg-x11-Xvnc
Requires:       xorg-x11-Xvnc:/usr/lib/vnc/with-vnc-key.sh
Recommends:     vncmanager-controller

Url:            https://github.com/michalsrb/vncmanager
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        Session manager for VNC
License:        MIT
Group:          System/X11/Utilities
Source:         vncmanager-%{version}.tar.gz
Source1:        tmpfile.conf
Patch1:         n_use_port_5901.patch
Patch2:         n_use_with_vnc_key_wrapper.patch
Patch3:         U_Add-xvnc-args-configuration-option.patch
Patch4:         n_disable_mit_shm.patch
Patch5:         U_ControllerConnection-Split-iostream-into-istream-and.patch
Patch6:         n_vncmanager-add-target-to-service.patch

%description
Session manager for VNC. It listens on VNC port and spawns Xvnc processes for incoming clients.

%pre
%service_add_pre vncmanager.service

%post
%service_add_post vncmanager.service
[ -x /usr/bin/systemd-tmpfiles ] && /usr/bin/systemd-tmpfiles --create %_tmpfilesdir/%{name}.conf || :

%preun
%service_del_preun vncmanager.service

%postun
%service_del_postun vncmanager.service

%prep
%setup
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCMAKE_VERBOSE_MAKEFILE=ON
make %{?_smp_mflags}

%install
%cmake_install

# tmpfiles
install -d -m 0755 %{buildroot}/usr/lib/tmpfiles.d/
install -m 0644 %{SOURCE1} %{buildroot}/usr/lib/tmpfiles.d/%{name}.conf

# systemd
mkdir -p %{buildroot}%{_sbindir}
ln -sf %{_sbindir}/service %{buildroot}%{_sbindir}/rcvncmanager

%files
%defattr(-,root,root)
%{_bindir}/vncmanager
%{_unitdir}/vncmanager.service
%{_sbindir}/rcvncmanager
%dir %attr(0755,%{vncuser},%{vncuser}) %{_sysconfdir}/vnc
%config(noreplace) %{_sysconfdir}/vnc/vncmanager.conf
/usr/lib/tmpfiles.d/%{name}.conf
%ghost %dir /run/vncmanager
%doc LICENSE

%changelog
* Mon Aug  6 2018 msrb@suse.com
- n_vncmanager-add-target-to-service.patch
  * Declare the service as part of xvnc.target so it can be used as
    dependency for xvnc-novnc.service. (bnc#1103552)
* Thu Feb 15 2018 msrb@suse.com
- U_ControllerConnection-Split-iostream-into-istream-and.patch
  * Do not try to seek on unix socket. (bnc#1076730)
* Fri Aug 11 2017 msrb@suse.com
- U_Add-xvnc-args-configuration-option.patch,
  n_disable_mit_shm.patch
  * Disable MIT-SHM extension in Xvnc started by vncmanager.
    (bnc#1053373)
* Mon May 22 2017 msrb@suse.com
- Update to 1.0.2
  * Fix crash when client disconnects during of TLS negotiation
  * Add geometry parameter (bnc#1038851)
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Thu Jun 16 2016 msrb@suse.com
- Update to 1.0.1
  * Fix build with gcc 6, fix licence link in README. (bnc#985002)
- Add dependency on xorg-x11-Xvnc. (bnc#984461)
- Add n_use_with_vnc_key_wrapper.patch
  * Use with-vnc-key.sh wrapper to generate VNC key and certificate
    on first use. (bnc#982349)
* Thu May 12 2016 msrb@suse.com
- Add LICENSE file to docs.
- Expand %%tmpfiles_create macro.
* Thu May  5 2016 jengelh@inai.de
- %%make_jobs is not defined in SLE; but we can use make %%_smp_mflags
- systemd is not a hard runtime requirement (the macros support
  softfail)
* Fri Apr 29 2016 msrb@suse.com
- Change group to System/X11/Utilities.
* Wed Apr 27 2016 msrb@suse.com
- Update to v1.0.0.
* Wed Apr 27 2016 msrb@suse.com
- n_use_port_5901.patch
  * Use port 5901 to match tigervnc's xinetd based service.
* Mon Nov  9 2015 msrb@suse.com
- Create package.
